==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebSummaryTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryResultDescriptionMetadata } from "./WebSummaryResultDescriptionMetadata";
import { WebSummaryTemplateContextDescription } from "./WebSummaryTemplateContextDescription";
/**
 * @hidden
 */
var WebSummaryTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebSummaryTemplateContextDescriptionMetadata, _super);
    function WebSummaryTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSummaryTemplateContextDescriptionMetadata.b = function (a) {
        if (WebSummaryTemplateContextDescriptionMetadata.a == null) {
            WebSummaryTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSummaryTemplateContextDescriptionMetadata.c(WebSummaryTemplateContextDescriptionMetadata.a);
        }
        if (a.j(WebSummaryTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.y(WebSummaryTemplateContextDescriptionMetadata.a);
        WebSummaryResultDescriptionMetadata.d(a);
    };
    WebSummaryTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SummaryTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Implicit", "Array:WebSummaryResultDescription:SummaryResult");
    };
    WebSummaryTemplateContextDescriptionMetadata.d = function (a) {
        WebSummaryTemplateContextDescriptionMetadata.b(a);
        a.aa("WebSummaryTemplateContext", function () { return new WebSummaryTemplateContextDescription(); });
        a.z("WebSummaryTemplateContext", WebSummaryTemplateContextDescriptionMetadata.a);
    };
    WebSummaryTemplateContextDescriptionMetadata.$t = markType(WebSummaryTemplateContextDescriptionMetadata, 'WebSummaryTemplateContextDescriptionMetadata');
    WebSummaryTemplateContextDescriptionMetadata.a = null;
    return WebSummaryTemplateContextDescriptionMetadata;
}(Base));
export { WebSummaryTemplateContextDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebSummaryTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryResultDescriptionMetadata } from "./WebSummaryResultDescriptionMetadata";
import { WebSummaryTemplateContextDescription } from "./WebSummaryTemplateContextDescription";
/**
 * @hidden
 */
var WebSummaryTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebSummaryTemplateContextDescriptionMetadata, _super);
    function WebSummaryTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSummaryTemplateContextDescriptionMetadata.b = function (a) {
        if (WebSummaryTemplateContextDescriptionMetadata.a == null) {
            WebSummaryTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSummaryTemplateContextDescriptionMetadata.c(WebSummaryTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebSummaryTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebSummaryTemplateContextDescriptionMetadata.a);
        WebSummaryResultDescriptionMetadata.d(a);
    };
    WebSummaryTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SummaryTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "Array:WebSummaryResultDescription:SummaryResult");
    };
    WebSummaryTemplateContextDescriptionMetadata.d = function (a) {
        WebSummaryTemplateContextDescriptionMetadata.b(a);
        a.ac("WebSummaryTemplateContext", function () { return new WebSummaryTemplateContextDescription(); });
        a.ab("WebSummaryTemplateContext", WebSummaryTemplateContextDescriptionMetadata.a);
    };
    WebSummaryTemplateContextDescriptionMetadata.$t = markType(WebSummaryTemplateContextDescriptionMetadata, 'WebSummaryTemplateContextDescriptionMetadata');
    WebSummaryTemplateContextDescriptionMetadata.a = null;
    return WebSummaryTemplateContextDescriptionMetadata;
}(Base));
export { WebSummaryTemplateContextDescriptionMetadata };
